.. _resnet:

Evolvable ResNet
=================

An evolvable version of the ResNet architecture for image observation spaces.

Parameters
------------

.. autoclass:: agilerl.modules.resnet.EvolvableResNet
  :members:
